==> kpmcore-2.1.0-1-armv6h.pkg.tar.xz: usr/include/kpmcore/fs/f2fs.h <==
/*************************************************************************
 *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(F2FS__H)

#define F2FS__H

#include "util/libpartitionmanagerexport.h"

#include "fs/filesystem.h"

#include <qglobal.h>

class Report;

class QString;

namespace FS
{
/** A f2fs file system.
    @author Andrius Štikonas <andrius@stikonas.eu>
*/
class LIBKPMCORE_EXPORT f2fs : public FileSystem
{
public:
    f2fs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);

public:
    static void init();

//          virtual qint64 readUsedCapacity(const QString& deviceNode) const;
    virtual bool check(Report& report, const QString& deviceNode) const;
    virtual bool create(Report& report, const QString& deviceNode) const;
//     virtual qint64 readUsedCapacity(const QString& deviceNode) const;
//     virtual bool resize(Report& report, const QString& deviceNode, qint64 length) const;
//     virtual bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel);
//     virtual bool updateUUID(Report& report, const QString& deviceNode) const;

    virtual CommandSupportType supportGetUsed() const {
        return m_GetUsed;
    }
    virtual CommandSupportType supportGetLabel() const {
        return m_GetLabel;
    }
    virtual CommandSupportType supportCreate() const {
        return m_Create;
    }
    virtual CommandSupportType supportGrow() const {
        return m_Grow;
    }
    virtual CommandSupportType supportShrink() const {
        return m_Shrink;
    }
    virtual CommandSupportType supportMove() const {
        return m_Move;
    }
    virtual CommandSupportType supportCheck() const {
        return m_Check;
    }
    virtual CommandSupportType supportCopy() const {
        return m_Copy;
    }
    virtual CommandSupportType supportBackup() const {
        return m_Backup;
    }
    virtual CommandSupportType supportSetLabel() const {
        return m_SetLabel;
    }
    virtual CommandSupportType supportUpdateUUID() const {
        return m_UpdateUUID;
    }
    virtual CommandSupportType supportGetUUID() const {
        return m_GetUUID;
    }

    virtual qint64 minCapacity() const;
    virtual qint64 maxCapacity() const;
    virtual qint64 maxLabelLength() const;
    virtual SupportTool supportToolName() const;
    virtual bool supportToolFound() const;

public:
    static CommandSupportType m_GetUsed;
    static CommandSupportType m_GetLabel;
    static CommandSupportType m_Create;
    static CommandSupportType m_Grow;
    static CommandSupportType m_Shrink;
    static CommandSupportType m_Move;
    static CommandSupportType m_Check;
    static CommandSupportType m_Copy;
    static CommandSupportType m_Backup;
    static CommandSupportType m_SetLabel;
    static CommandSupportType m_UpdateUUID;
    static CommandSupportType m_GetUUID;
};
}

#endif

==> kpmcore-2.2.1-1-armv6h.pkg.tar.xz: usr/include/kpmcore/fs/f2fs.h <==
/*************************************************************************
 *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(F2FS__H)

#define F2FS__H

#include "util/libpartitionmanagerexport.h"

#include "fs/filesystem.h"

#include <QtGlobal>

class Report;

class QString;

namespace FS
{
/** A f2fs file system.
    @author Andrius Štikonas <andrius@stikonas.eu>
*/
class LIBKPMCORE_EXPORT f2fs : public FileSystem
{
public:
    f2fs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);

public:
    void init() override;

//          qint64 readUsedCapacity(const QString& deviceNode) const override;
    bool check(Report& report, const QString& deviceNode) const override;
    bool create(Report& report, const QString& deviceNode) const override;
//     qint64 readUsedCapacity(const QString& deviceNode) const override;
//     bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
//     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
//     bool updateUUID(Report& report, const QString& deviceNode) const override;

    CommandSupportType supportGetUsed() const override {
        return m_GetUsed;
    }
    CommandSupportType supportGetLabel() const override {
        return m_GetLabel;
    }
    CommandSupportType supportCreate() const override {
        return m_Create;
    }
    CommandSupportType supportGrow() const override {
        return m_Grow;
    }
    CommandSupportType supportShrink() const override {
        return m_Shrink;
    }
    CommandSupportType supportMove() const override {
        return m_Move;
    }
    CommandSupportType supportCheck() const override {
        return m_Check;
    }
    CommandSupportType supportCopy() const override {
        return m_Copy;
    }
    CommandSupportType supportBackup() const override {
        return m_Backup;
    }
    CommandSupportType supportSetLabel() const override {
        return m_SetLabel;
    }
    CommandSupportType supportUpdateUUID() const override {
        return m_UpdateUUID;
    }
    CommandSupportType supportGetUUID() const override {
        return m_GetUUID;
    }

    qint64 minCapacity() const override;
    qint64 maxCapacity() const override;
    qint64 maxLabelLength() const override;
    SupportTool supportToolName() const override;
    bool supportToolFound() const override;

public:
    static CommandSupportType m_GetUsed;
    static CommandSupportType m_GetLabel;
    static CommandSupportType m_Create;
    static CommandSupportType m_Grow;
    static CommandSupportType m_Shrink;
    static CommandSupportType m_Move;
    static CommandSupportType m_Check;
    static CommandSupportType m_Copy;
    static CommandSupportType m_Backup;
    static CommandSupportType m_SetLabel;
    static CommandSupportType m_UpdateUUID;
    static CommandSupportType m_GetUUID;
};
}

#endif
